@@ -25,6 +25,11 @@
 //! [InMemoryClient] is used. Usually this would be some client which really accesses
 //! remote BLOBs.
 //!
+//! The [Condow] struct itself can be used to download BLOBs. It might not be
+//! convinient to pass it around since it has 2 type parameters. Consider the
+//! traits [Downloads] (which has only an associated type) or [DownloadUntyped]
+//! (which is even object safe) to pass around instances of [Condow].
+//!
 //! ```
 //! use condow_core::condow_client::InMemoryClient;
 //! use condow_core::{Condow, config::Config};
@@ -81,7 +86,7 @@ use anyhow::Error as AnyError;
 use futures::{future::BoxFuture, FutureExt};
 
 use condow_client::CondowClient;
-use config::{AlwaysGetSize, ClientRetryWrapper, Config};
+use config::{ClientRetryWrapper, Config};
 use errors::CondowError;
 use machinery::ProbeInternal;
 use probe::{Probe, ProbeFactory};
@@ -112,7 +117,7 @@ pub mod test_utils;
 /// This trait is not object safe. If you want to use dynamic dispatch you
 /// might consider the trait [DownloadsUntyped] which is object safe
 /// and accepts string slices as a location.
-pub trait Downloads {
+pub trait Downloads: Send + Sync + 'static {
     type Location: std::fmt::Debug + std::fmt::Display + Clone + Send + Sync + 'static;
 
     /// Download a BLOB via the returned request object
@@ -180,7 +185,7 @@ pub trait Downloads {
 /// assert_eq!(blob, b"a remote BLOB");
 /// # }
 /// ```
-pub trait DownloadsUntyped {
+pub trait DownloadsUntyped: Send + Sync + 'static {
     /// Download a BLOB via the returned request object
     fn blob(&self) -> RequestNoLocation<&str>;
 
@@ -309,18 +314,11 @@ where
                 (Some(req), Some(fac)) => ProbeInternal::Two(fac, req),
             };
 
-            machinery::download_range(
-                condow.client,
-                condow.config,
-                location,
-                params.range,
-                params.get_size_mode,
-                probe,
-            )
-            .boxed()
+            machinery::download_range(condow.client, params.config, location, params.range, probe)
+                .boxed()
         };
 
-        RequestNoLocation::new(download_fn)
+        RequestNoLocation::new(download_fn, self.config.clone())
     }
 
     /// Get the size of a BLOB at the given location
@@ -406,18 +404,11 @@ where
                 (Some(req), Some(fac)) => ProbeInternal::Two(fac, req),
             };
 
-            machinery::download_range(
-                condow.client,
-                condow.config,
-                location,
-                params.range,
-                params.get_size_mode,
-                probe,
-            )
-            .boxed()
+            machinery::download_range(condow.client, params.config, location, params.range, probe)
+                .boxed()
         };
 
-        RequestNoLocation::new(download_fn)
+        RequestNoLocation::new(download_fn, self.config.clone())
     }
 
     fn get_size<'a>(&'a self, location: &str) -> BoxFuture<'a, Result<u64, CondowError>> {
@@ -457,38 +448,6 @@ where
     }
 }
 
-/// Overide the behaviour when [Condow] does a request to get
-/// the size of a BLOB
-#[derive(Debug, Copy, Clone, PartialEq, Eq)]
-pub enum GetSizeMode {
-    /// Request a size on open ranges and also closed ranges
-    /// so that a given upper bound can be adjusted/corrected
-    Always,
-    /// Only request the size of a BLOB when required. This is when an open
-    /// range (e.g. complete BLOB or from x to end)
-    Required,
-    /// As configured with [Condow] itself.
-    ///
-    /// This is the default value.
-    Default,
-}
-
-impl GetSizeMode {
-    fn is_load_size_enforced(self, always_by_default: AlwaysGetSize) -> bool {
-        match self {
-            GetSizeMode::Always => true,
-            GetSizeMode::Required => false,
-            GetSizeMode::Default => always_by_default.into_inner(),
-        }
-    }
-}
-
-impl Default for GetSizeMode {
-    fn default() -> Self {
-        Self::Default
-    }
-}
-
 #[cfg(test)]
 mod condow_tests;
 
